Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(782)

Unified Diff: chrome/browser/ui/gtk/gtk_theme_service.h

Issue 10337010: Revert r123782. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/gtk/global_menu_bar.cc ('k') | chrome/browser/ui/gtk/gtk_theme_service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/gtk/gtk_theme_service.h
diff --git a/chrome/browser/ui/gtk/theme_service_gtk.h b/chrome/browser/ui/gtk/gtk_theme_service.h
similarity index 94%
rename from chrome/browser/ui/gtk/theme_service_gtk.h
rename to chrome/browser/ui/gtk/gtk_theme_service.h
index c00c62abc8d9d2063b091159d8b8734e99a1f75f..d5b288a91a48ffe5a5887e282f1768dcbb1398bb 100644
--- a/chrome/browser/ui/gtk/theme_service_gtk.h
+++ b/chrome/browser/ui/gtk/gtk_theme_service.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_GTK_THEME_SERVICE_GTK_H_
-#define CHROME_BROWSER_UI_GTK_THEME_SERVICE_GTK_H_
+#ifndef CHROME_BROWSER_UI_GTK_GTK_THEME_SERVICE_H_
+#define CHROME_BROWSER_UI_GTK_GTK_THEME_SERVICE_H_
#pragma once
#include <map>
@@ -37,7 +37,7 @@ typedef struct _GtkStyle GtkStyle;
typedef struct _GtkWidget GtkWidget;
// Specialization of ThemeService which supplies system colors.
-class ThemeServiceGtk : public ThemeService {
+class GtkThemeService : public ThemeService {
public:
// A list of integer keys for a separate PerDisplaySurfaceMap that keeps
// what would otherwise be static icons on the X11 server.
@@ -48,11 +48,11 @@ class ThemeServiceGtk : public ThemeService {
CHROME_FOLDER
};
- // Returns ThemeServiceGtk, casted from our superclass.
- static ThemeServiceGtk* GetFrom(Profile* profile);
+ // Returns GtkThemeService, casted from our superclass.
+ static GtkThemeService* GetFrom(Profile* profile);
- ThemeServiceGtk();
- virtual ~ThemeServiceGtk();
+ GtkThemeService();
+ virtual ~GtkThemeService();
// Calls |observer|.Observe() for the browser theme with this provider as the
// source.
@@ -223,15 +223,15 @@ class ThemeServiceGtk : public ThemeService {
void GetSelectedEntryForegroundHSL(color_utils::HSL* tint) const;
// Handles signal from GTK that our theme has been changed.
- CHROMEGTK_CALLBACK_1(ThemeServiceGtk, void, OnStyleSet, GtkStyle*);
+ CHROMEGTK_CALLBACK_1(GtkThemeService, void, OnStyleSet, GtkStyle*);
// A notification from various GObject destructors that we should
// remove it from our internal list.
- CHROMEGTK_CALLBACK_0(ThemeServiceGtk, void, OnDestroyChromeButton);
- CHROMEGTK_CALLBACK_0(ThemeServiceGtk, void, OnDestroyChromeLinkButton);
- CHROMEGTK_CALLBACK_0(ThemeServiceGtk, void, OnDestroyLabel);
+ CHROMEGTK_CALLBACK_0(GtkThemeService, void, OnDestroyChromeButton);
+ CHROMEGTK_CALLBACK_0(GtkThemeService, void, OnDestroyChromeLinkButton);
+ CHROMEGTK_CALLBACK_0(GtkThemeService, void, OnDestroyLabel);
- CHROMEGTK_CALLBACK_1(ThemeServiceGtk, gboolean, OnSeparatorExpose,
+ CHROMEGTK_CALLBACK_1(GtkThemeService, gboolean, OnSeparatorExpose,
GdkEventExpose*);
// Whether we should be using gtk rendering.
@@ -299,4 +299,4 @@ class ThemeServiceGtk : public ThemeService {
static gfx::Image* default_bookmark_icon_;
};
-#endif // CHROME_BROWSER_UI_GTK_THEME_SERVICE_GTK_H_
+#endif // CHROME_BROWSER_UI_GTK_GTK_THEME_SERVICE_H_
« no previous file with comments | « chrome/browser/ui/gtk/global_menu_bar.cc ('k') | chrome/browser/ui/gtk/gtk_theme_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698